.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xset_operation
==============

Defined in ``xtensor/xset_operation.hpp``

.. doxygenenum:: xt::isin(E&&, F&&)
   :project: xtensor

.. doxygenenum:: xt::in1d(E&&, F&&)
   :project: xtensor

.. doxygenenum:: xt::searchsorted(E1&&, E2&&, bool)
   :project: xtensor

Further overloads
-----------------

.. doxygenenum:: xt::isin(E&&, std::initializer_list<T>)
   :project: xtensor

.. doxygenenum:: xt::isin(E&&, I&&, I&&)
   :project: xtensor

.. doxygenenum:: xt::in1d(E&&, std::initializer_list<T>)
   :project: xtensor

.. doxygenenum:: xt::in1d(E&&, I&&, I&&)
   :project: xtensor
